Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1826)

Unified Diff: ash/mus/move_event_handler.h

Issue 2905893002: chromeos: convert more ash/wm code to aura::Window (Closed)
Patch Set: moar cleanup Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/mus/move_event_handler.h
diff --git a/ash/mus/move_event_handler.h b/ash/mus/move_event_handler.h
index 8854c452e7fdf99d46026d54ce604fc61d0f013c..db76a5e02665192ade42c46e3f8abccb6bfbbc02 100644
--- a/ash/mus/move_event_handler.h
+++ b/ash/mus/move_event_handler.h
@@ -23,8 +23,6 @@ class CancelModeEvent;
namespace ash {
-class WmWindow;
-
namespace mus {
class WorkspaceEventHandlerMus;
@@ -40,8 +38,8 @@ class MoveEventHandler : public ui::EventHandler, public aura::WindowObserver {
aura::Window* window);
~MoveEventHandler() override;
- // Retrieves the MoveEventHandler for an existing WmWindow.
- static MoveEventHandler* GetForWindow(WmWindow* wm_window);
+ // Retrieves the MoveEventHandler for an existing aura::Window.
+ static MoveEventHandler* GetForWindow(aura::Window* window);
// Attempts to start a drag if one is not already in progress. This passes
// the call to the underlying WmToplevelWindowEventHandler. After the drag
@@ -75,7 +73,7 @@ class MoveEventHandler : public ui::EventHandler, public aura::WindowObserver {
// Overridden from aura::WindowObserver:
void OnWindowDestroying(aura::Window* window) override;
- WmWindow* wm_window_;
+ aura::Window* window_;
aura::WindowManagerClient* window_manager_client_;
wm::WmToplevelWindowEventHandler toplevel_window_event_handler_;

Powered by Google App Engine
This is Rietveld 408576698